import vcr

from pytest import fixture
from fivbvis import Article

#Single Article
@fixture
def article_get_keys():
    return {'data': {'no', 'source', 'publishOnHome', 'videoUri', 'isVideoLive'}}

@vcr.use_cassette('tests/vcr_cassettes/article-get-data.yaml')
def test_article_get(article_get_keys):
    #API call to GET a Article data

    article_get_instance = Article()
    response = article_get_instance.get(28639, 'No')

    assert isinstance(response, dict)
    assert response['data']['no'] == 28639, 'The Article Number should be in the response'
    assert set(article_get_keys).issubset(response.keys()), 'All keys should be in the response'


import vcr

from pytest import fixture
from fivbvis import VolleyMatch

#Single Match
@fixture
def volley_match_keys():
    return {'data': {'no', 'dateTimeLocal', 'city', 'hall', 'teamA', 'teamB', 'tournament'}}

@vcr.use_cassette('tests/vcr_cassettes/volley-match-data.yaml')
def test_volley_match(volley_match_keys):
    #API call to GET a Volleyball match data

    volley_match_instance = VolleyMatch()
    response = volley_match_instance.match(7604)

    assert isinstance(response, dict)
    assert response['data']['no'] == 7604, 'The Match Number should be in the response'
    assert set(volley_match_keys).issubset(response.keys()), 'All keys should be in the response'

#Match List
@fixture
def volley_list_keys():
    return {'data': [{'no', 'teamA', 'teamB', 'noTournament'}, {'no', 'teamA', 'teamB', 'noTournament'}]}

@vcr.use_cassette('tests/vcr_cassettes/volley-list-data.yaml')
def test_volley_list(volley_list_keys):
    #API call to GET a Volleyball list data

    volley_list_instance = VolleyMatch()
    response = volley_list_instance.list(979, "no teamA teamB noTournament", "FirstDate='2017-07-01' LastDate='2017-07-31'")

    assert isinstance(response, dict)

    assert response['data'][0]['noTournament'] == 979, 'The Tournament Number of the first match should be in the response'
    assert response['data'][1]['noTournament'] == 979, 'The Tournament Number of the second match should be in the response'

    assert response['data'][0]['no'] == 7595, 'The first Match Number should be in the response'
    assert response['data'][1]['no'] == 7596, 'The second Match Number should be in the response'

    assert set(volley_list_keys).issubset(response.keys()), 'All keys should be in the response'


import requests

class Article():
    def __init__(self):
        self.headers = {'Accept': 'application/json'}
        self.base_url = "https://www.fivb.org/Vis2009/XmlRequest.asmx?Request="

    def get(self, no, fields=''):
        url = self.base_url + "<Request Type='GetArticle' No='{}' Fields='{}'/>".format(no, fields)

        response = requests.get(url, headers=self.headers)

        return response.json()


from setuptools import setup, find_packages
import re

with open('README.md', 'r', encoding='utf-8') as f:
    long_description = f.read()

with open('requirements.txt', 'r', encoding='utf-8') as f:
    install_requires = f.read().splitlines()

with open('fivbvis/version.py', 'r', encoding='utf-8') as f:
    version = re.search(r"^__version__\s*=\s*'(.*)'.*$",
        f.read(), flags=re.MULTILINE).group(1)

setup(
    name='fivbvis',
    version=version,
    author='claromes',
    license='GPLv3',
    description='FIVB VIS Web Service Python Client',
    long_description=long_description,
    long_description_content_type='text/markdown',
    keywords='api-wrapper fivbvis fivb volleyball beachvolleyball',
    url='https://github.com/claromes/fivbvis',
    packages=find_packages(exclude=['docs', 'tests*']),
    classifiers=[
        'Development Status :: 3 - Alpha',
        'Intended Audience :: Science/Research',
        'Intended Audience :: Education',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: GNU General Public License v3 (GPLv3)',
        'Operating System :: OS Independent',
        'Programming Language :: Python',
        'Programming Language :: Python :: 3.8',
        'Topic :: Scientific/Engineering',
        'Topic :: Scientific/Engineering :: Information Analysis',
        'Topic :: Software Development',
        'Topic :: Software Development :: Libraries :: Python Modules',
        'Topic :: Utilities'
    ],
    python_requires='>=3.8',
    install_requires=install_requires
)


import requests

class VolleyMatch():
    def __init__(self):
        self.headers = {'Accept': 'application/json'}
        self.base_url = "https://www.fivb.org/Vis2009/XmlRequest.asmx?Request="

    def match(self, no):
        url = self.base_url + "<Request Type='GetVolleyMatch' No='{}' />".format(no)

        response = requests.get(url, headers=self.headers)

        return response.json()

    def list(self, no_tournament, fields, filter=''):
        url = self.base_url + "<Request Type='GetVolleyMatchList' Fields='{}'><Filter {} NoTournament='{}' /></Request>".format(fields, filter, no_tournament)

        response = requests.get(url, headers=self.headers)

        return response.json()